import Vue from "vue";
export declare type Option = {
    value: unknown;
    label: string | number;
} | [string | number, unknown] | Record<string | number, unknown>;
/**
 * @see https://element.eleme.cn/#/zh-CN/component/form#biao-dan-yan-zheng
 * @see https://github.com/yiminghe/async-validator
 */
export interface Rule {
    required?: boolean;
    message?: string;
    trigger?: "change" | "blur";
    validator?: (rule: unknown, value: unknown, callback: (err?: Error) => void) => void | boolean | Error | Error[];
}
/**
 * 表单条目函数
 * 条目对象属性如下：
 * {string} prop
 * {string} label
 * {enum} type: input, daterange, select
 * 默认input
 * {boolean} required
 * {boolean} disabled
 * {object|array<object>} rules
 * {number} span, el-col span, 默认值6/8
 * {*|function} default, 字段默认值可以为函数
 * {array<{value: *, label: *}>} options, select组件options
 * option类型为object或者只包含两个元素的array
 * 第一元素为value，第二个元素为label
 * {string} slot 插槽name
 * {boolean} filterable
 * {boolean} remote
 * {boolean} loading
 * {function} remoteMethod,
 * {string|array<string>} classes form item classes
 * {string} valueFormat 日期值格式化字符串，默认`yyyy-MM-dd`
 * {string} format 日期显示格式化字符串
 * {function} blur
 * {function} input
 */
export interface Item {
    prop: string;
    label: string;
    type?: "input" | "daterange" | "date" | "select";
    required?: boolean;
    disabled?: boolean;
    rules?: Rule | Rule[];
    span?: number;
    default?: unknown | (() => unknown);
    options?: Option[];
    slot?: string;
    filterable?: boolean;
    remote?: boolean;
    loading?: boolean;
    remoteMethod?: () => void;
    classes?: string | string[];
    valueFormat?: string;
    format?: string;
    blur?: () => void;
    input?: () => void;
}
declare function defaultModel(items: Item[]): Record<string, unknown>;
declare function optionValue(option: Option): unknown;
declare function optionLabel(option: Option): string | number;
declare const _default: import("vue/types/vue").ExtendedVue<Vue, unknown, {
    resetFields(): void;
    clearValidate(): void;
    validate(): void;
}, unknown, {
    labelPosition: string;
    labelWidth: string | number;
    model: Record<string, unknown>;
    items: () => Item[];
    change: (model: Record<string, unknown>) => void;
}>;
export default _default;
export { defaultModel, optionValue, optionLabel };
