import Vue from "vue";
import { VNodeData, VNodeChildren } from "vue/types/vnode";
interface This extends Vue {
    _selectedData: unknown[];
    _currentRow: null | unknown;
    tableData: unknown[];
    total: number;
    data: unknown[] | null;
    autoLoad: boolean;
    mCurrentPage: number;
    mPageSize: number;
    loading: boolean;
    pageList: (opts: {
        page: number;
        pageSize: number;
    }, ...rest: unknown[]) => Promise<{
        tableData: unknown[];
        total: number;
        page?: number;
        pageSize?: number;
    }>;
}
export interface Column<Row = unknown> {
    label: string;
    prop?: string;
    align?: "left" | "center" | "right";
    formatter?: (row: Row) => unknown;
    /**
     * px单位宽度, 注意不带px
     */
    width?: string | number;
    /**
     * px单位宽度, 注意不带px
     */
    minWidth?: string | number;
    /**
     * 自定义列表头渲染函数
     */
    renderHeader?: (row: Row) => unknown;
    /**
     * 自定义列插槽name
     */
    slot?: string;
    /**
     * 自定义列表头插槽name
     */
    header?: string;
    hidden?: boolean;
}
declare const _default: import("vue/types/vue").ExtendedVue<Vue, {
    mCurrentPage: number;
    mPageSize: number;
    total: number;
    mPageSizes: number[];
    tableData: never[];
    loading: boolean;
}, {
    handlePageChg(this: This, currentPage: number): This;
    handleSizeChg(this: This, pageSize: number): This;
    handleSelectionChg(this: This, selectedData: unknown[]): void;
    handleCurrentChange(currentRow: unknown, oldRow: unknown): void;
    handleRowClk(this: This, row: unknown, column: unknown, event: Event): void;
    handleHeaderClick(column: unknown, event: Event): void;
    /**
     * 外部组件通过ref主动更新table data
     */
    pageLists(this: This, ...rest: unknown[]): Promise<void>;
    /**
     * 获取选中行数据
     * @returns {array<*>}
     */
    selectedData(this: This): unknown[];
    clearSelection(this: This): This;
    getData(): unknown[];
}, {
    mData: unknown[];
    mColumns: Column<unknown>[];
}, {
    currentPage: number;
    pageSize: number;
    pageSizes: number[];
    data: unknown[];
    columns: () => Column[];
    pageList: (...rest: unknown[]) => Promise<void>;
    rowKey: (row: unknown) => string | number;
    border: boolean;
    withSelection: boolean;
    withIndex: boolean;
    indexName: string;
    withPagination: boolean;
    autoLoad: boolean;
    highlightCurrentRow: boolean;
    cellStyle: ({ row, column, rowIndex, columnIndex }: {
        row: unknown;
        column: unknown;
        rowIndex: number;
        columnIndex: number;
    }) => Record<string, string | number>;
    pagerCount: number;
    showOverflowTooltip: boolean;
    actions: VNodeData | [VNodeData, VNodeChildren];
    "row-click": (row: unknown, column: unknown, event: Event) => void;
    "current-change": (currentRow: unknown, oldRow: unknown) => void;
    "check-list": (selectedData: unknown[]) => void;
    "header-click": (column: unknown, event: Event) => void;
}>;
export default _default;
