import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import Vue from 'vue';
import { TableColumn, Loading, Pagination, Table } from 'element-ui';
import { f as fixJsxImport } from '../../utils/fixJsxImport.js';
var modules_0806e81c = {
  "container": "index_module_container__57aafa7b",
  "paginationBox": "index_module_paginationBox__57aafa7b"
};
fixJsxImport(Table, TableColumn, Pagination);
Loading.install(Vue);
var index = Vue.extend({
  name: "Table",
  props: {
    currentPage: {
      type: Number,
      "default": 1
    },
    pageSize: {
      type: Number,
      "default": 10
    },
    pageSizes: {
      type: Array,
      "default": function _default() {
        return [10, 20, 30, 40, 50];
      }
    },

    /**
     * 如果外部传递data优先用响应式table data
     * pageList就可以不用传递
     */
    data: {
      type: Array,
      "default": null
    },

    /**
     * 表格列定义函数
     * column options
     * {string} label
     * {string} align
     * {string} prop
     * {function} formatter
     * {string} width px单位宽度, 注意不带px
     * {string} minWidth px单位宽度, 注意不带px
     * {boolean} hidden
     * {string} slot 自定义列插槽name
     * {string} header 自定义列表头插槽name
     * {function} renderHeader 自定义列表头渲染函数
     */
    columns: {
      type: Function,
      "default": null
    },

    /**
     * 表格数据获取函数
     */
    pageList: {
      type: Function,
      "default": null
    },
    rowKey: {
      type: Function,
      "default": null
    },
    border: {
      type: Boolean,
      "default": true
    },

    /**
     * 是否提供行选择复选框
     */
    withSelection: {
      type: Boolean,
      "default": false
    },
    withIndex: {
      type: Boolean,
      "default": false
    },

    /**
     * index表头名称，默认为序号
     */
    indexName: {
      type: String,
      "default": "序号"
    },

    /**
     * 默认下单页时不显示分页组件
     */
    withPagination: {
      type: Boolean,
      "default": true
    },

    /**
     * 是否自动调用pageList加载分页数据
     * 默认true
     */
    autoLoad: {
      type: Boolean,
      "default": true
    },
    highlightCurrentRow: {
      type: Boolean,
      "default": false
    },

    /**
     * @see https://element.eleme.cn/#/zh-CN/component/table#table-attributes
     */
    cellStyle: {
      type: Function,
      "default": undefined
    },
    pagerCount: {
      type: Number,
      "default": 7
    },
    showOverflowTooltip: {
      type: Boolean,
      "default": true
    },

    /**
     * element ui el-table-column插槽在渲染函数中$parent失效
     * 请通过actions属性传递操作列VNodeData和VNodeChildren
     */
    actions: {
      type: [Object, Array],
      "default": undefined
    },
    "row-click": {
      type: Function,
      "default": null
    },
    "current-change": {
      type: Function,
      "default": null
    },
    "check-list": {
      type: Function,
      "default": null
    },
    "header-click": {
      type: Function,
      "default": null
    }
  },
  data: function data() {
    return {
      mCurrentPage: this.currentPage,
      mPageSize: this.pageSize,
      total: 0,
      mPageSizes: this.pageSizes,
      tableData: [],
      loading: false
    };
  },
  beforeCreate: function beforeCreate() {
    this._selectedData = [];
    this._currentRow = null;
  },
  mounted: function mounted() {
    // 如果外部传递了table data数据源
    // 优先以外部响应式数据更新table data
    if (!this.data && this.autoLoad) {
      pageList.call(this);
    }
  },
  computed: {
    mData: function mData() {
      return this.data || this.tableData;
    },
    mColumns: function mColumns() {
      var _this$columns;

      // 修复v-if和v-for共用lint错误
      // The 'mColumns' variable inside 'v-for' directive should be replaced with a computed property that returns filtered array
      // instead. You should not mix 'v-for' with 'v-if'  vue/no-use-v-if-with-v-for
      return (_this$columns = this.columns() // hidden属性控制列显示隐藏
      ) === null || _this$columns === void 0 ? void 0 : _this$columns.filter(function (column) {
        return !column.hidden;
      });
    }
  },
  methods: {
    handlePageChg: function handlePageChg(currentPage) {
      return pageChg.call(this, currentPage, this.mPageSize);
    },
    handleSizeChg: function handleSizeChg(pageSize) {
      return pageChg.call(this, this.mCurrentPage, pageSize);
    },
    handleSelectionChg: function handleSelectionChg(selectedData) {
      this._selectedData = selectedData;
      this.$emit("check-list", selectedData);
    },
    handleCurrentChange: function handleCurrentChange(currentRow, oldRow) {
      this.$emit("current-change", currentRow, oldRow);
    },
    handleRowClk: function handleRowClk(row, column, event) {
      // row click事件晚于current-change事件
      if (this._currentRow === row) {
        // toggle select
        this.$refs.table.setCurrentRow(null);
        this._currentRow = null;
      } else {
        this._currentRow = row;
      }

      this.$emit("row-click", row, column, event);
    },
    handleHeaderClick: function handleHeaderClick(column, event) {
      this.$emit("header-click", column, event);
    },
    // 对外API
    // ===================================

    /**
     * 外部组件通过ref主动更新table data
     */
    pageLists: function pageLists() {
      for (var _len = arguments.length, rest = new Array(_len), _key = 0; _key < _len; _key++) {
        rest[_key] = arguments[_key];
      }

      return pageList.apply(this, rest);
    },

    /**
     * 获取选中行数据
     * @returns {array<*>}
     */
    selectedData: function selectedData() {
      return this._selectedData;
    },
    clearSelection: function clearSelection() {
      this.$refs.table.clearSelection();
      this._selectedData = [];
      return this;
    },
    getData: function getData() {
      return this.mData;
    }
  },
  render: function render(h) {
    var _this = this;

    var ActionNode;

    if (this.actions) {
      var args;

      if (Array.isArray(this.actions)) {
        args = this.actions;
      } else {
        args = [this.actions];
      }

      ActionNode = [h.apply(void 0, [TableColumn].concat(_toConsumableArray(args)))];
    } else {
      ActionNode = this.$slots.actions;
    }

    return h("div", {
      "class": modules_0806e81c.container
    }, [h(Table, {
      "ref": "table",
      "props": {
        "data": this.mData,
        "rowKey": this.rowKey,
        "border": this.border,
        "highlightCurrentRow": this.highlightCurrentRow,
        "cellStyle": this.cellStyle
      },
      "directives": [{
        name: "loading",
        value: this.loading
      }],
      "on": {
        "current-change": this.handleCurrentChange,
        "selection-change": this.handleSelectionChg,
        "row-click": this.handleRowClk,
        "header-click": this.handleHeaderClick
      }
    }, [this.withSelection && h(TableColumn, {
      "props": {
        "type": "selection",
        "width": 50
      }
    }), this.withIndex && h(TableColumn, {
      "props": {
        "type": "index",
        "label": this.indexName
      },
      "scopedSlots": {
        "default": function _default(scope) {
          return indexMethod(scope.$index, _this.mCurrentPage, _this.mPageSize).toString();
        }
      }
    }), this.mColumns.map(function (column) {
      var scopedSlots = {};

      if (column.header) {
        scopedSlots.header = function () {
          var _this$$scopedSlots$co, _this$$scopedSlots;

          return (_this$$scopedSlots$co = (_this$$scopedSlots = _this.$scopedSlots)[column.header]) === null || _this$$scopedSlots$co === void 0 ? void 0 : _this$$scopedSlots$co.call(_this$$scopedSlots, {
            column: column
          });
        };
      }

      if (column.slot) {
        scopedSlots["default"] = function (_ref) {
          var _this$$scopedSlots$co2, _this$$scopedSlots2;

          var row = _ref.row;
          return (_this$$scopedSlots$co2 = (_this$$scopedSlots2 = _this.$scopedSlots)[column.slot]) === null || _this$$scopedSlots$co2 === void 0 ? void 0 : _this$$scopedSlots$co2.call(_this$$scopedSlots2, {
            row: row
          });
        };
      }

      return h(TableColumn, {
        "key": column.label,
        "props": {
          "showOverflowTooltip": _this.showOverflowTooltip,
          "align": column.align,
          "prop": column.prop,
          "formatter": column.formatter,
          "label": column.label,
          "width": column.width,
          "minWidth": column.minWidth,
          "renderHeader": column.renderHeader
        },
        "scopedSlots": scopedSlots
      });
    }), ActionNode]), this.withPagination && h("div", {
      "class": modules_0806e81c.paginationBox
    }, [h(Pagination, {
      "props": {
        "currentPage": this.mCurrentPage,
        "pageSizes": this.mPageSizes,
        "pageSize": this.mPageSize,
        "total": this.total,
        "pagerCount": this.pagerCount,
        "layout": "total, sizes, prev, pager, next, jumper"
      },
      "on": {
        "current-change": this.handlePageChg,
        "size-change": this.handleSizeChg
      }
    })])]);
  }
});

function pageChg(currentPage, pageSize) {
  this.mCurrentPage = currentPage;
  this.mPageSize = pageSize;
  pageList.call(this);
  return this;
}

function pageList() {
  return _pageList.apply(this, arguments);
} // 表格序号


function _pageList() {
  _pageList = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var result,
        _len2,
        rest,
        _key2,
        _result,
        tableData,
        page,
        pageSize,
        total,
        _args = arguments;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            result = undefined;
            _context.prev = 1;
            this.loading = true;

            for (_len2 = _args.length, rest = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
              rest[_key2] = _args[_key2];
            }

            _context.next = 6;
            return this.pageList.apply(this, [{
              // 后端统一为page名字
              page: this.mCurrentPage,
              pageSize: this.mPageSize // 传递额外参数到外部pageList方法

            }].concat(rest));

          case 6:
            _context.t0 = _context.sent;

            if (_context.t0) {
              _context.next = 9;
              break;
            }

            _context.t0 = {
              tableData: [],
              total: 0
            };

          case 9:
            result = _context.t0;

          case 10:
            _context.prev = 10;
            this.loading = false;
            return _context.finish(10);

          case 13:
            _result = result, tableData = _result.tableData, page = _result.page, pageSize = _result.pageSize, total = _result.total;

            if (tableData !== undefined) {
              this.tableData = tableData;
            }

            if (page !== undefined) {
              this.mCurrentPage = page;
            }

            if (pageSize !== undefined) {
              this.mPageSize = pageSize;
            }

            if (total !== undefined) {
              this.total = total;
            }

          case 18:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[1,, 10, 13]]);
  }));
  return _pageList.apply(this, arguments);
}

function indexMethod(index, page, pageSize) {
  return index + 1 + (page - 1) * pageSize;
}

export default index;
